@@ -17,6 +17,7 @@
 
 SessionManager::SessionManager(QObject *parent) : QObject(parent)
 {
+    DLOG << "SessionManager";
     _trans_workers.clear();
     // Create session and transfer worker
     _session_worker = std::make_shared<SessionWorker>();
@@ -32,17 +33,21 @@ SessionManager::SessionManager(QObject *parent) : QObject(parent)
 
 SessionManager::~SessionManager()
 {
+    DLOG << "~SessionManager";
     if (_file_counter) {
+        DLOG << "Stopping file counter";
         _file_counter->stop();
         _file_counter.reset();
     }
 
     if (_session_worker) {
+        DLOG << "Stopping session worker";
         _session_worker->stop();
         _session_worker.reset();
     }
 
     // release all transfer worker.
+    DLOG << "Releasing all transfer workers";
     auto it = _trans_workers.begin();
     while (it != _trans_workers.end()) {
         it->second->stop();
@@ -55,37 +60,45 @@ SessionManager::~SessionManager()
 
 void SessionManager::setSessionExtCallback(ExtenMessageHandler cb)
 {
+    DLOG << "setSessionExtCallback";
     _session_worker->setExtMessageHandler(cb);
 }
 
 void SessionManager::updatePin(QString code)
 {
+    DLOG << "updatePin: " << code.toStdString();
     _session_worker->updatePincode(code);
 }
 
 void SessionManager::setStorageRoot(const QString &root)
 {
+    DLOG << "setStorageRoot: " << root.toStdString();
     _save_root = QString(root);
 }
 
 void SessionManager::updateSaveFolder(const QString &folder)
 {
+    DLOG << "updateSaveFolder: " << folder.toStdString();
     if (_save_root.isEmpty()) {
         _save_root = QStandardPaths::writableLocation(QStandardPaths::DownloadLocation);
+        DLOG << "Save root is empty, setting to default download location:" << _save_root.toStdString();
     }
     _save_dir = _save_root + QDir::separator();
     if (!folder.isEmpty()) {
         _save_dir += folder + QDir::separator();
+        DLOG << "Save folder updated:" << _save_dir.toStdString();
     }
 }
 
 void SessionManager::updateLoginStatus(QString &ip, bool logined)
 {
+    DLOG << "updateLoginStatus ip: " << ip.toStdString() << " logined: " << logined;
     _session_worker->updateLogin(ip, logined);
 }
 
 void SessionManager::sessionListen(int port)
 {
+    DLOG << "sessionListen: " << port;
     bool success = _session_worker->startListen(port);
     if (!success) {
         ELOG << "Fail to start listen: " << port;
@@ -103,8 +116,10 @@ bool SessionManager::sessionPing(QString ip, int port)
 int SessionManager::sessionConnect(QString ip, int port, QString password)
 {
     LOG << "sessionConnect: " << ip.toStdString();
-    if (_session_worker->isClientLogin(ip))
+    if (_session_worker->isClientLogin(ip)) {
+        DLOG << "Client is already logged in:" << ip.toStdString();
         return 1;
+    }
     if (!_session_worker->netTouch(ip, port)) {
         ELOG << "Fail to connect remote:" << ip.toStdString();
         return -1;
@@ -132,6 +147,7 @@ void SessionManager::sessionDisconnect(QString ip)
 
 std::shared_ptr<TransferWorker> SessionManager::createTransWorker(const QString &jobid)
 {
+    
     // Create a new TransferWorker
     auto newWorker = std::make_shared<TransferWorker>(jobid);
     // auto newWorker = QSharedPointer<TransferWorker>::create(this);
@@ -144,8 +160,10 @@ std::shared_ptr<TransferWorker> SessionManager::createTransWorker(const QString
 
 void SessionManager::releaseTransWorker(const QString &jobid)
 {
+    DLOG << "releaseTransWorker jobid: " << jobid.toStdString();
     auto it = _trans_workers.find(jobid);
     if (it != _trans_workers.end()) {
+        DLOG << "Releasing transfer worker for job ID:" << jobid.toStdString();
         it->second->stop();
         disconnect(it->second.get(), nullptr, nullptr, nullptr);
 
@@ -157,6 +175,7 @@ void SessionManager::releaseTransWorker(const QString &jobid)
 
 void SessionManager::sendFiles(QString &ip, int port, QStringList paths)
 {
+    LOG << "sendFiles: " << ip.toStdString();
     std::vector<std::string> name_vector;
     std::string token;
 
@@ -173,6 +192,7 @@ void SessionManager::sendFiles(QString &ip, int port, QStringList paths)
     QString endpoint = QString("%1:%2:%3").arg(localIp).arg(port).arg(accesstoken);
     int64_t total = _file_counter->countFiles(ip, paths);
     bool needCount = total == 0;
+    DLOG << "Sending files, needCount:" << needCount << "total size:" << total;
 
     TransDataMessage req;
     req.id = ip.toStdString();
@@ -185,6 +205,7 @@ void SessionManager::sendFiles(QString &ip, int port, QStringList paths)
     sendRpcRequest(ip, REQ_TRANS_DATAS, jsonMsg);
 
     if (total > 0) {
+        DLOG << "Total size is known, handling transfer count";
         QString oneName = paths.join(";");
         handleTransCount(oneName, total);
     }
@@ -192,6 +213,7 @@ void SessionManager::sendFiles(QString &ip, int port, QStringList paths)
 
 void SessionManager::recvFiles(QString &ip, int port, QString &token, QStringList names)
 {
+    
     auto worker = createTransWorker(ip);
     bool success = worker->tryStartReceive(names, ip, port, token, _save_dir);
     if (!success) {
@@ -210,6 +232,7 @@ void SessionManager::cancelSyncFile(const QString &ip, const QString &reason)
         // no need to cancel sync file if net_error, or it will cause ui block.
         WLOG << "net_error, no need to cancel sync file";
     } else {
+        DLOG << "Sending cancel RPC request";
         // first: send cancel rpc, target jobid is self ip addr.
         TransCancelMessage req;
         req.id = deepin_cross::CommonUitls::getFirstIp();
@@ -221,11 +244,13 @@ void SessionManager::cancelSyncFile(const QString &ip, const QString &reason)
     }
 
     // then: stop local worker
+    DLOG << "Stopping local worker";
     handleCancelTrans(ip, reason);
 }
 
 void SessionManager::sendRpcRequest(const QString &ip, int type, const QString &reqJson)
 {
+    DLOG << "sendRpcRequest to: " << ip.toStdString();
     proto::OriginMessage request;
     request.mask = type;
     request.json_msg = reqJson.toStdString();
@@ -238,8 +263,10 @@ void SessionManager::sendRpcRequest(const QString &ip, int type, const QString &
 
 void SessionManager::handleTransData(const QString endpoint, const QStringList nameVector)
 {
+    DLOG << "handleTransData from: " << endpoint.toStdString();
     QStringList parts = endpoint.split(":");
     if (parts.length() == 3) {
+        DLOG << "Handling transfer data for endpoint:" << endpoint.toStdString();
         // 现在ip、port和token中分别包含了拆解后的内容
         recvFiles(parts[0], parts[1].toInt(), parts[2], nameVector);
     } else {
@@ -250,19 +277,23 @@ void SessionManager::handleTransData(const QString endpoint, const QStringList n
 
 void SessionManager::handleTransCount(const QString names, quint64 size)
 {
+    DLOG << "handleTransCount names: " << names.toStdString();
     // TRANS_COUNT_SIZE = 50
     emit notifyTransChanged(50, names, size);
 }
 
 void SessionManager::handleCancelTrans(const QString jobid, const QString reason)
 {
+    DLOG << "handleCancelTrans jobid: " << jobid.toStdString();
     // stop & release the worker
     releaseTransWorker(jobid);
 
     if (!reason.isEmpty()) {
+        DLOG << "Handling transfer cancellation with reason:" << reason.toStdString();
         // TRANS_EXCEPTION = 49
         emit notifyTransChanged(49, reason, 0);
     } else {
+        DLOG << "Handling transfer cancellation by user";
         // TRANS_CANCELED = 48 by user
         emit notifyTransChanged(48, "", 0);
     }
@@ -270,10 +301,12 @@ void SessionManager::handleCancelTrans(const QString jobid, const QString reason
 
 void SessionManager::handleFileCounted(const QString ip, const QStringList paths, quint64 totalSize)
 {
+    DLOG << "handleFileCounted ip: " << ip.toStdString();
     if (ip.isEmpty()) {
         WLOG << "empty target address for file counted.";
         return;
     }
+    DLOG << "Handling file counted for ip:" << ip.toStdString() << "total size:" << totalSize;
     std::vector<std::string> nameVector;
     foreach (const QString &path, paths) {
         nameVector.push_back(path.toStdString());
@@ -290,6 +323,7 @@ void SessionManager::handleFileCounted(const QString ip, const QStringList paths
     sendRpcRequest(ip, INFO_TRANS_COUNT, jsonMsg);
 
     // notify local
+    DLOG << "Notifying local about file count";
     QString oneName = paths.join(";");
     handleTransCount(oneName, totalSize);
 }
