@@ -91,9 +91,12 @@ TransferHelperPrivate::~TransferHelperPrivate()
 void TransferHelperPrivate::initConnect()
 {
 #ifdef __linux__
+    DLOG << "Linux platform, initializing NoticeUtil";
     notice = new NoticeUtil(q);
     connect(notice, &NoticeUtil::onConfirmTimeout, q, &TransferHelper::onVerifyTimeout);
     connect(notice, &NoticeUtil::ActionInvoked, q, &TransferHelper::onActionTriggered);
+#else
+    DLOG << "Non-Linux platform, skipping NoticeUtil initialization";
 #endif
 
     confirmTimer.setInterval(10 * 1000);
@@ -130,6 +133,12 @@ void TransferHelperPrivate::notifyMessage(const QString &body, const QStringList
 {
 #ifdef __linux__
     notice->notifyMessage(tr("File transfer"), body, actions, hitMap, expireTimeout);
+#else
+    Q_UNUSED(body)
+    Q_UNUSED(actions)
+    Q_UNUSED(expireTimeout)
+    Q_UNUSED(hitMap)
+    DLOG << "Non-Linux platform, skipping notification message";
 #endif
 }
 
@@ -228,10 +237,13 @@ void TransferHelper::buttonClicked(const QString &id, const DeviceInfoPointer in
         if (selectedFiles.isEmpty())
             selectedFiles = QFileDialog::getOpenFileNames(qApp->activeWindow());
 
-        if (selectedFiles.isEmpty())
+        if (selectedFiles.isEmpty()) {
+            DLOG << "No files selected, returning";
             return;
+        }
 
         if (qApp->property("onlyTransfer").toBool()) {
+            DLOG << "onlyTransfer is true, sending command to local socket";
             // send command to local socket.
             QStringList msgs;
             // must be in the format of: <ip> <name> <files>
@@ -239,6 +251,7 @@ void TransferHelper::buttonClicked(const QString &id, const DeviceInfoPointer in
             emit TransferHelper::instance()->deliverMessage(MainAppName, msgs);
             qApp->exit(0);
         } else {
+            DLOG << "onlyTransfer is false, sending files";
             TransferHelper::instance()->sendFiles(ip, name, selectedFiles);
         }
     } else if (id == HistoryButtonId) {
@@ -263,15 +276,22 @@ bool TransferHelper::buttonVisible(const QString &id, const DeviceInfoPointer in
     }
 
     if (id == HistoryButtonId) {
-        if (qApp->property("onlyTransfer").toBool())
+        DLOG << "Button ID is HistoryButtonId";
+        if (qApp->property("onlyTransfer").toBool()) {
+            DLOG << "onlyTransfer is true, returning false";
             return false;
+        }
 
-        if (!transHistory->contains(info->ipAddress()))
+        if (!transHistory->contains(info->ipAddress())) {
+            DLOG << "Transfer history does not contain IP, returning false";
             return false;
+        }
 
         bool exists = QFile::exists(transHistory->value(info->ipAddress()));
-        if (!exists)
+        if (!exists) {
+            DLOG << "File does not exist, removing from history";
             HistoryManager::instance()->removeTransHistory(info->ipAddress());
+        }
 
         return exists;
     }
@@ -306,14 +326,17 @@ void TransferHelper::transferResult(bool result, const QString &msg)
 {
 #ifdef __linux__
     if (d->role != Server) {
+        DLOG << "Role is not Server, closing notification";
         d->notice->closeNotification(); // close previous progress notification
 
         QStringList actions;
         if (result) {
+            DLOG << "Transfer successful, adding view action";
             actions << NotifyViewAction << tr("View");
             auto hints = d->createViewFileHints(d->recvFilesSavePath);
             d->notifyMessage(msg, actions, -1, hints);
         } else {
+            DLOG << "Transfer failed, showing message";
             d->notifyMessage(msg, {}, 3 * 1000);
         }
         return;
@@ -328,6 +351,7 @@ void TransferHelper::updateProgress(int value, const QString &remainTime)
 {
 #ifdef __linux__
     if (d->role != Server) {
+        DLOG << "Role is not Server, updating notification";
         // 在通知中心中，如果通知内容包含“%”且actions中存在“cancel”，则不会在通知中心显示
         QStringList actions { NotifyCancelAction, tr("Cancel") };
         // dde-session-ui 5.7.2.2 版本后，支持设置该属性使消息不进通知中心
@@ -348,34 +372,44 @@ void TransferHelper::updateProgress(int value, const QString &remainTime)
 
 void TransferHelper::onActionTriggered(const QString &action)
 {
+    DLOG << "Action triggered:" << action.toStdString();
     // clear transfer info
     d->transferInfo.clear();
     if (action == NotifyCancelAction) {
+        DLOG << "Action is NotifyCancelAction";
         cancelTransfer(true); // do UI first
         NetworkUtil::instance()->cancelTrans(d->targetDeviceIp);
     } else if (action == NotifyRejectAction) {
+        DLOG << "Action is NotifyRejectAction";
         NetworkUtil::instance()->replyTransRequest(false, d->targetDeviceIp);
     } else if (action == NotifyAcceptAction) {
+        DLOG << "Action is NotifyAcceptAction";
         d->role = Client;
         NetworkUtil::instance()->replyTransRequest(true, d->targetDeviceIp);
     } else if (action == NotifyCloseAction) {
+        DLOG << "Action is NotifyCloseAction";
 #ifdef __linux__
         d->notice->closeNotification();
 #endif
     } else if (action == NotifyViewAction) {
+        DLOG << "Action is NotifyViewAction";
         auto fileurl = d->recvFilesSavePath;
         if (fileurl.isEmpty()) {
+            DLOG << "Received files save path is empty, getting from config";
             auto value = ConfigManager::instance()->appAttribute(AppSettings::GenericGroup, AppSettings::StoragePathKey);
             fileurl = value.isValid() ? value.toString() : QStandardPaths::writableLocation(QStandardPaths::DownloadLocation);
         }
 
         // has been opened by notify center
         // openFileLocation(fileurl);
+    } else {
+        DLOG << "Unknown action:" << action.toStdString();
     }
 }
 
 void TransferHelper::openFileLocation(const QString &path)
 {
+    DLOG << "Opening file location:" << path.toStdString();
 #ifdef __linux__
     QProcess::execute("dde-file-manager", QStringList() << path);
 #else
@@ -395,6 +429,7 @@ void TransferHelper::notifyTransferRequest(const QString &nick, const QString &i
     d->who = nick;
     d->targetDeviceIp = ip;
 #ifdef __linux__
+    DLOG << "Linux platform, sending notification";
 
     QStringList actions { NotifyRejectAction, tr("Reject"),
                           NotifyAcceptAction, tr("Accept"),
@@ -413,6 +448,7 @@ void TransferHelper::handleCancelTransferApply()
 #ifdef __linux__
     d->notifyMessage(body, {}, 3 * 1000);
 #else
+    DLOG << "Non-Linux platform, showing result dialog";
     d->transDialog()->showResultDialog(false, body);
 #endif
 }
@@ -421,13 +457,19 @@ void TransferHelper::onConnectStatusChanged(int result, const QString &msg, cons
 {
     LOG << "connect status: " << result << " msg:" << msg.toStdString();
     if (result > 0) {
-        if (!isself)
+        DLOG << "Connection successful";
+        if (!isself) {
+            DLOG << "Not self connection, returning";
             return;
+        }
 
         d->status.storeRelease(Confirming);
     } else {
-        if (Idle == d->status.loadAcquire())
+        DLOG << "Connection failed";
+        if (Idle == d->status.loadAcquire()) {
+            DLOG << "Status is Idle, returning";
             return;
+        }
 
         d->status.storeRelease(Idle);
         transferResult(false, tr("Connect to \"%1\" failed").arg(msg));
@@ -445,6 +487,7 @@ void TransferHelper::onTransChanged(int status, const QString &path, quint64 siz
         cancelTransfer(false);
         break;
     case TRANS_EXCEPTION:
+        DLOG << "Transfer exception occurred";
         // exception reason: "io_error" "net_error" "not_found" "fs_exception"
         d->status.storeRelease(Idle);
         if (path == "io_error") {
@@ -459,6 +502,7 @@ void TransferHelper::onTransChanged(int status, const QString &path, quint64 siz
         }
         break;
     case TRANS_COUNT_SIZE:
+        DLOG << "Transfer count size updated";
         // only update the total size while rpc notice
         d->transferInfo.totalSize = size;
         break;
@@ -471,6 +515,7 @@ void TransferHelper::onTransChanged(int status, const QString &path, quint64 siz
         DLOG << "Transfer completed successfully";
         d->status.storeRelease(Idle);
         if (d->role == Client) {
+            DLOG << "Client role, setting received files save path";
             d->recvFilesSavePath = NetworkUtil::instance()->getStorageFolder();
             DLOG << "Files saved to:" << d->recvFilesSavePath.toStdString();
             HistoryManager::instance()->writeIntoTransHistory(NetworkUtil::instance()->getConfirmTargetAddress(), d->recvFilesSavePath);
@@ -484,6 +529,7 @@ void TransferHelper::onTransChanged(int status, const QString &path, quint64 siz
         DLOG << "Current transfer file changed to:" << path.toStdString();
         break;
     case TRANS_FILE_SPEED: {
+        DLOG << "Transfer file speed updated";
         d->transferInfo.transferSize += size;
         d->transferInfo.maxTimeS += 1;   // 每1秒收到此信息
         updateTransProgress(d->transferInfo.transferSize);
@@ -496,6 +542,9 @@ void TransferHelper::onTransChanged(int status, const QString &path, quint64 siz
     case TRANS_FILE_DONE:
         DLOG << "File transfer completed:" << path.toStdString();
         break;
+    default:
+        DLOG << "Unknown transfer status:" << status;
+        break;
     }
 }
 
