@@ -28,6 +28,7 @@ ConnectWidget::~ConnectWidget()
 
 void ConnectWidget::initUI()
 {
+    DLOG << "ConnectWidget initUI";
     setStyleSheet(".ConnectWidget{background-color: white; border-radius: 10px;}");
 
     QVBoxLayout *mainLayout = new QVBoxLayout();
@@ -49,6 +50,7 @@ void ConnectWidget::initUI()
     downloadLabel->setContentsMargins(0, 10, 0, 0);
     downloadLabel->setText(QString("<a href=\"https://\" style=\"text-decoration:none;\">%1</a>").arg(tr("Download Windows client")));
     connect(downloadLabel, &QLabel::linkActivated, this, [] {
+        DLOG << "Download Windows client link activated";
         QDesktopServices::openUrl(QUrl("https://www.chinauos.com/resource/deepin-data-transfer"));
     });
 
@@ -93,10 +95,12 @@ void ConnectWidget::initUI()
     mainLayout->addLayout(buttonLayout);
     mainLayout->addSpacing(10);
     mainLayout->addLayout(indexLayout);
+    DLOG << "ConnectWidget initUI finished";
 }
 
 void ConnectWidget::initConnectLayout()
 {
+    DLOG << "ConnectWidget initConnectLayout";
     //ipLayout
     QList<QHostAddress> address = QNetworkInterface::allAddresses();
     QString ipaddress = address.count() > 2 ? address[2].toString() : "";
@@ -169,10 +173,12 @@ void ConnectWidget::initConnectLayout()
     QTimer *timer = new QTimer();
     connect(timer, &QTimer::timeout, [refreshLabel, tipLabel, passwordLabel, nullLabel, timer, this]() {
         if (remainingTime > 0 && !passwordLabel->text().isEmpty()) {
+            DLOG << "Remaining time:" << remainingTime << "s";
             remainingTime--;
             QString tip = QString("%1<font color='#6199CA'> %2s </font>%3").arg(tr("The code will be expired in")).arg(QString::number(remainingTime)).arg(tr("please input connect code as soon as possible"));
             tipLabel->setText(tip);
         } else {
+            DLOG << "Connect code expired or password label is empty";
             tipLabel->setVisible(false);
             passwordLabel->setVisible(false);
             nullLabel->setVisible(true);
@@ -218,6 +224,7 @@ void ConnectWidget::initConnectLayout()
     connectLayout->addLayout(passwordVLayout);
     connectLayout->setSpacing(15);
     connectLayout->setAlignment(Qt::AlignCenter);
+    DLOG << "ConnectWidget initConnectLayout finished";
 }
 
 void ConnectWidget::nextPage()
@@ -231,9 +238,11 @@ void ConnectWidget::backPage()
     DLOG << "Returning to previous page";
     QStackedWidget *stackedWidget = qobject_cast<QStackedWidget *>(this->parent());
     if (stackedWidget) {
+        DLOG << "Stacked widget found, setting current index to previous page";
         stackedWidget->setCurrentIndex(stackedWidget->currentIndex() - 1);
     } else {
         WLOG << "Jump to next page failed, qobject_cast<QStackedWidget *>(this->parent()) = nullptr";
+        DLOG << "Stacked widget not found";
     }
 }
 
@@ -243,12 +252,14 @@ void ConnectWidget::themeChanged(int theme)
 
     // light
     if (theme == 1) {
+        DLOG << "Theme is light, setting stylesheet";
         setStyleSheet(".ConnectWidget{background-color: rgba(255,255,255,1); border-radius: 10px;}");
         separatorLabel->setStyleSheet("QLabel { background-color: rgba(0, 0, 0, 0.1); width: 2px; }");
         ipLabel->setStyleSheet(" ");
         ipLabel1->setStyleSheet(" ");
     } else {
         // dark
+        DLOG << "Theme is dark, setting stylesheet";
         setStyleSheet(".ConnectWidget{background-color: rgba(37, 37, 37,1); border-radius: 10px;}");
         separatorLabel->setStyleSheet("background-color: rgba(220, 220, 220,0.1); width: 2px;");
         ipLabel->setStyleSheet("color: rgb(192, 192, 192);");
